==> agrosyst-cli-1.4.9-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesModel.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesModel.java 4837 2015-03-17 15:48:52Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.9/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesModel.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.SeedingActionSpecies;
import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;

/**
 * Created by davidcosse on 12/02/15.
 */
public class SeedingActionSpeciesModel extends AbstractAgrosystModelExtended<SeedingActionSpeciesImportDto> {

    protected SeedingActionSpeciesModel() {
        super(';');
        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("quantity", "quantityWithNull", DOUBLE_WITH_NULL_AND_9999_PARSER);
        newMandatoryColumn("deepness", SeedingActionSpecies.PROPERTY_DEEPNESS, DOUBLE_WITH_NULL_AND_9999_PARSER);
        newMandatoryColumn("speciescode", SeedingActionSpecies.PROPERTY_SPECIES_CODE);
        newMandatoryColumn("seedplantunit", "seedPlantUnitName");
        newMandatoryColumn("seedingaction", "seedingActionId");
        newMandatoryColumn("treatment", SeedingActionSpecies.PROPERTY_TREATMENT, T_F_PARSER);
        newMandatoryColumn("biologicalseedinoculation", SeedingActionSpecies.PROPERTY_BIOLOGICAL_SEED_INOCULATION, T_F_PARSER);
    }

    @Override
    public SeedingActionSpeciesImportDto newEmptyInstance() {
        return new SeedingActionSpeciesImportDto();
    }
}

==> agrosyst-cli-1.5.1-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesModel.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesModel.java 5028 2015-07-10 06:33:13Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5.1/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesModel.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.SeedingActionSpecies;
import fr.inra.agrosyst.services.pz0import.AbstractAgrosystModelExtended;

/**
 * Created by davidcosse on 12/02/15.
 */
class SeedingActionSpeciesModel extends AbstractAgrosystModelExtended<SeedingActionSpeciesImportDto> {

    SeedingActionSpeciesModel() {
        super();
        newMandatoryColumn("topiaid", "id");
        newIgnoredColumn("topiaversion");
        newIgnoredColumn("topiacreatedate");
        newMandatoryColumn("quantity", "quantityWithNull", DOUBLE_WITH_NULL_AND_9999_PARSER);
        newMandatoryColumn("deepness", SeedingActionSpecies.PROPERTY_DEEPNESS, DOUBLE_WITH_NULL_AND_9999_PARSER);
        newMandatoryColumn("speciescode", SeedingActionSpecies.PROPERTY_SPECIES_CODE);
        newMandatoryColumn("seedplantunit", "seedPlantUnitName");
        newMandatoryColumn("seedingaction", "seedingActionId");
        newMandatoryColumn("treatment", SeedingActionSpecies.PROPERTY_TREATMENT, T_F_PARSER);
        newMandatoryColumn("biologicalseedinoculation", SeedingActionSpecies.PROPERTY_BIOLOGICAL_SEED_INOCULATION, T_F_PARSER);
    }

    @Override
    public SeedingActionSpeciesImportDto newEmptyInstance() {
        return new SeedingActionSpeciesImportDto();
    }
}
